<?php
/*
Plugin Name: Whop Telegram Notification
Version: 1.0.0
Plugin URI: https:/rusdy.com/whop-telegram-notification
Author: Rusdy
Author URI: https:/rusdy.com/
Description: Get a notification to your Telegram account/group for Woocommerce new order.
Text Domain: whop-telegram-notification
*/

if (!defined('ABSPATH')) {
	exit;
}
if (!class_exists('wt_notification')) {

	class wt_notification {

		var $plugin_version = '1.0.0';

		function __construct() {
			define('wt_notification_VERSION', $this->plugin_version);
			$this->plugin_includes();
		}

		function plugin_includes() {
			if (is_admin()) {
				add_filter('plugin_action_links', array($this, 'plugin_action_links'), 10, 2);
			}
			add_action('admin_init', array($this, 'settings_api_init'));
			add_action('admin_menu', array($this, 'add_options_menu'));
			add_action('woocommerce_thankyou', array($this, 'wt_send_to_telegram'));
		}

		function plugin_url() {
			if ($this->plugin_url)
				return $this->plugin_url;
			return $this->plugin_url = plugins_url(basename(plugin_dir_path(__FILE__)), basename(__FILE__));
		}

		function plugin_action_links($links, $file) {
			if ($file == plugin_basename(dirname(__FILE__) . '/main.php')) {
				$links[] = '<a href="options-general.php?page=whop-telegram-notification">'.__('Settings', 'whop-telegram-notification').'</a>';
			}
			return $links;
		}

		function add_options_menu() {
			if (is_admin()) {
				add_options_page(__('WT Notification', 'whop-telegram-notification'), __('WT Notification', 'whop-telegram-notification'), 'manage_options', 'whop-telegram-notification', array($this, 'options_page'));
			}
		}

		function settings_api_init(){
			register_setting( 'wtnotification', 'wt_notification' );

			add_settings_section(
				'wt_notification_section',
				__('General Settings', 'whop-telegram-notification'),
				array($this, 'wt_notification_section_callback'),
				'wtnotification'
				);

			add_settings_field(
				'wtn_id',
				__('Your User ID', 'whop-telegram-notification'),
				array($this, 'wtn_id_render'),
				'wtnotification',
				'wt_notification_section'
				);
		}

		function wtn_id_render() {
			$options = get_option('wt_notification');
			?>
			<input type='number' name='wt_notification[wtn_id]' value='<?php echo $options['wtn_id']; ?>'>
			<?php
		}

		function wt_notification_section_callback() {}

		function options_page() {
			?>
			<div class="wrap">
				<h2>Whop Telegram Notification</h2>
				<div class="update-nag">
					<p class="description"><?php printf(__('<a target="_blank" href="https://t.me/WhopBot">Click here to message</a> @WhopBot on Telegram and type /start', 'whop-telegram-notification'), '12345678');?></p>
				</div>
				<form action='options.php' method='post'>
					<?php
					settings_fields( 'wtnotification' );
					do_settings_sections( 'wtnotification' );
					submit_button();
					?>
				</form>
			</div>
			<?php
		}

		function is_logged_in(){
			$is_logged_in = false;
            if(is_user_logged_in()){ //the user is logged in
            	if(current_user_can('editor') || current_user_can('administrator')){
            		$is_logged_in = true;
            	}
            }
            return $is_logged_in;
        }

        function wt_send_to_telegram( $order_id ) {
        	$options = get_option('wt_notification');
        	$order = wc_get_order( $order_id );
        	$items = $order->get_items();

        	$product_name = '';
        	foreach ( $items as $item ) {
        		$product_name .= $item['name'];
        	}

        	$info = "Order ID ".$order->id."\nProduct Name: ".$product_name."\nBuyer Name : ".$order->billing_first_name." ".$order->billing_last_name."\nBuyer Email: ".$order->billing_email."\nBuyer Phone: ".$order->billing_phone."\nTotal: ".$order->currency." ".$order->total."\n\nManage : ".admin_url( 'post.php?post='.$order->id.'&action=edit' );

        	$txt = get_bloginfo('name')." : You've got new order! \n\n".$info;
        	$telegram = 'https://bot.rusdy.com/message.php?chatid='.$options['wtn_id'].'&text='.urlencode($txt);
        	$ch = curl_init();
        	curl_setopt($ch, CURLOPT_URL, $telegram);
        	curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        	$output = curl_exec($ch);
        }

    }

    $GLOBALS['wt_notification'] = new wt_notification();
}